CREATE TABLE  V_SOCIETES
(STE_NUM NUMBER,          -- Cle unique sequentielle
	STE_LIB VARCHAR2(100),   -- le nom qui permettra de la selectionner
	STE_REM VARCHAR2(255),   -- descriptif eventuel
	STE_NOM_RESP VARCHAR2(255),   -- nom du responsable
	STE_TELF_RESP VARCHAR2(255),   -- tel fixe du responsable
	STE_TELM_RESP VARCHAR2(255),   -- tel mobile du responsable
	STE_MAIL1_RESP VARCHAR2(255),   -- mail1 fixe du responsable
	STE_ADR  VARCHAR2(255), -- Adresse
	STE_CPO VARCHAR2(5), -- Code postal
	STE_VILLE VARCHAR2(255), -- ville
  STE_LATITUDE VARCHAR2(255), -- latitude
  STE_LONGITUDE VARCHAR2(255), 	-- longitude
  STE_SLOGAN VARCHAR2(255), -- Slogan commercial
  STE_IMAGE BLOB,              -- Photo article   
	STE_TYPEMIME VARCHAR2(255),    -- type mime
	STE_NOMFICHIER VARCHAR2(400),  -- nom fichier Photo
	STE_DATE_MODIFICATION DATE,   -- date modification Photo

	CONSTRAINT V_SOCIETES_PK PRIMARY KEY (STE_NUM) ENABLE
   );
/


CREATE SEQUENCE   V_SOCIETES_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_SOCIETES_BI
  before insert on V_SOCIETES               
  for each row  
begin   
    select V_SOCIETES_SEQ.nextval into :NEW.STE_NUM from dual; 
end; 

/
ALTER TRIGGER  V_SOCIETES_BI ENABLE;
/

INSERT INTO V_SOCIETES (STE_LIB, STE_NOM_RESP, STE_TELF_RESP, STE_TELM_RESP, STE_MAIL1_RESP, STE_ADR, STE_CPO, STE_VILLE, STE_LATITUDE, STE_LONGITUDE) 
VALUES ('Venus', 'Hugo BOURGEOIS', '0472414200', '0665095601', 'hugo.bourgeois@laposte.net', 'PLACE Alain CHAPEL', '01390', 'MIONNAY', '4.9308265', '45.8954913');
/

CREATE TABLE  V_TVA
(TVA_NUM NUMBER,          -- Cle unique sequentielle
  TVA_STE NUMBER,          -- Societe
	TVA_LIBELLE VARCHAR2(100),   -- libelle
  TVA_TAUX NUMBER(4,2),   -- Pourcentage TVA

	CONSTRAINT V_TVA_PK PRIMARY KEY (TVA_NUM) ENABLE,
	
	CONSTRAINT V_TVA_FK1 FOREIGN KEY (TVA_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE	
   );
/


CREATE SEQUENCE   V_TVA_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_TVA_BI
  before insert on V_TVA               
  for each row  
begin   
    select V_TVA_SEQ.nextval into :NEW.TVA_NUM from dual; 
end; 

/
ALTER TRIGGER  V_TVA_BI ENABLE;
/

INSERT INTO V_TVA (TVA_STE, TVA_LIBELLE, TVA_TAUX) VALUES ('1', 'Taux normal', '18,60');
/

CREATE TABLE  V_SERVICES 
(SRV_NUM NUMBER,          -- Cle unique sequentielle
  SRV_STE NUMBER,          -- l'organisme auquel ce service est rattache
	SRV_LIB VARCHAR2(100),   -- le nom qui permettra de le selectionner
	SRV_REM VARCHAR2(255),   -- descriptif eventuel
	SRV_NOM_RESP VARCHAR2(255),   -- nom du responsable
	SRV_TELF_RESP VARCHAR2(255),   -- tel fixe du responsable
	SRV_TELM_RESP VARCHAR2(255),   -- tel mobile du responsable
	SRV_MAIL1_RESP VARCHAR2(255),   -- mail1 fixe du responsable

	CONSTRAINT V_SERVICES_PK PRIMARY KEY (SRV_NUM) ENABLE,
	
	CONSTRAINT V_SERVICES_FK1 FOREIGN KEY (SRV_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE
   );
/

CREATE SEQUENCE   V_SERVICES_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_SERVICES_BI
  before insert on V_SERVICES               
  for each row  
begin   
    select V_SERVICES_SEQ.nextval into :NEW.SRV_NUM from dual; 
end; 

/
ALTER TRIGGER  V_SERVICES_BI ENABLE;
/

INSERT INTO V_SERVICES (SRV_STE, SRV_LIB, SRV_NOM_RESP, SRV_TELF_RESP, SRV_MAIL1_RESP) VALUES ('1', 'Commercial', 'Herv MARION', '0472414201', 'herve.marion@laposte.net');
/
INSERT INTO V_SERVICES (SRV_STE, SRV_LIB, SRV_NOM_RESP, SRV_TELF_RESP, SRV_MAIL1_RESP) VALUES ('1', 'Comptabilit', 'Dominique FLAIR', '0472414202', 'dominique.flair@laposte.net');
/
INSERT INTO V_SERVICES (SRV_STE, SRV_LIB, SRV_NOM_RESP, SRV_TELF_RESP, SRV_MAIL1_RESP) VALUES ('1', 'Achat', 'Ali BADOUR', '0472414203', 'ali.badour@laposte.net');
/
INSERT INTO V_SERVICES (SRV_STE, SRV_LIB, SRV_NOM_RESP, SRV_TELF_RESP, SRV_MAIL1_RESP) VALUES ('1', 'Direction', 'Bakoly JAVAH', '0472414209', 'bakoly.javah.@laposte.net');
/

CREATE TABLE  V_QUALIFICATIONS
(QUA_NUM NUMBER,          -- Cle unique sequentielle
  QUA_STE NUMBER,          -- Societe
	QUA_NOM_ABREGE VARCHAR2(100),   -- Nom court
	QUA_NOM_COMPLET VARCHAR2(255),   -- Nom complet
  QUA_SALAN_DEBUTANT NUMBER(7,2),   -- Salaire annuel debutant
  QUA_SALAN_CONFIRME NUMBER(7,2),   -- Salaire annuel confirme  

	CONSTRAINT V_QUALIFICATIONS_PK PRIMARY KEY (QUA_NUM) ENABLE,
	
	CONSTRAINT V_QUALIFICATIONS_FK1 FOREIGN KEY (QUA_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE	
   );
/


CREATE SEQUENCE   V_QUALIFICATIONS_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_QUALIFICATIONS_BI
  before insert on V_QUALIFICATIONS               
  for each row  
begin   
    select V_QUALIFICATIONS_SEQ.nextval into :NEW.QUA_NUM from dual; 
end; 

/
ALTER TRIGGER  V_QUALIFICATIONS_BI ENABLE;
/

INSERT INTO V_QUALIFICATIONS (QUA_STE, QUA_NOM_ABREGE, QUA_NOM_COMPLET, QUA_SALAN_DEBUTANT, QUA_SALAN_CONFIRME) VALUES ('1', 'Vendeur', 'Attach commercial', '20000', '35000');
/
INSERT INTO V_QUALIFICATIONS (QUA_STE, QUA_NOM_ABREGE, QUA_NOM_COMPLET, QUA_SALAN_DEBUTANT, QUA_SALAN_CONFIRME) VALUES ('1', 'Comptable', 'Comptable', '18000', '25000');
/
INSERT INTO V_QUALIFICATIONS (QUA_STE, QUA_NOM_ABREGE, QUA_NOM_COMPLET, QUA_SALAN_DEBUTANT, QUA_SALAN_CONFIRME) VALUES ('1', 'Grant', 'Grant', '25000', '40000');
/
INSERT INTO V_QUALIFICATIONS (QUA_STE, QUA_NOM_ABREGE, QUA_NOM_COMPLET, QUA_SALAN_DEBUTANT, QUA_SALAN_CONFIRME) VALUES ('1','Livreur', 'Livreur', '15000', '18000');
/
INSERT INTO V_QUALIFICATIONS (QUA_STE, QUA_NOM_ABREGE, QUA_NOM_COMPLET, QUA_SALAN_DEBUTANT, QUA_SALAN_CONFIRME) VALUES ('1', 'Secrtaire', 'Secrtaire', '15000', '19000');
/
INSERT INTO V_QUALIFICATIONS (QUA_STE, QUA_NOM_ABREGE, QUA_NOM_COMPLET, QUA_SALAN_DEBUTANT, QUA_SALAN_CONFIRME) VALUES ('1', 'Acheteur', 'Acheteur', '17000', '22000');
/


CREATE TABLE  V_SALARIES 
(SLR_NUM NUMBER,          -- Cle unique sequentielle
  SLR_STE NUMBER,          -- Societe
  SLR_SRV NUMBER,            -- Service
	SLR_NOM VARCHAR2(100),   -- le Nom 
	SLR_PRENOM VARCHAR2(255),   -- tel mobile
  SLR_QUA NUMBER, -- Qualification
  SLR_SALAN_BRUT NUMBER(7,2), -- Salaire brut annuel
  SLR_TX_COMMISSION NUMBER(2,1),        -- taux commission vente

	CONSTRAINT V_SALARIES_PK PRIMARY KEY (SLR_NUM) ENABLE,
	
	CONSTRAINT V_SALARIES_FK1 FOREIGN KEY (SLR_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE,	
	CONSTRAINT V_SALARIES_FK2 FOREIGN KEY (SLR_SRV) REFERENCES V_SERVICES (SRV_NUM) ENABLE,
	CONSTRAINT V_SALARIES_FK3 FOREIGN KEY (SLR_QUA) REFERENCES V_QUALIFICATIONS (QUA_NUM) ENABLE
   );
/


CREATE SEQUENCE   V_SALARIES_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_SALARIES_BI
  before insert on V_SALARIES              
  for each row  
begin   
    select V_SALARIES_SEQ.nextval into :NEW.SLR_NUM from dual; 
end; 

/
ALTER TRIGGER  V_SALARIES_BI ENABLE;
/

INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT) VALUES ('1', '4', 'BOURGEOIS', 'Hugo', '3', '34000');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT) VALUES ('1', '4', 'JAVAH', 'Bakoly', '5', '16500');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT, SLR_TX_COMMISSION) VALUES ('1', '1', 'MARION', 'Herv', '1', '29000', '4');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT, SLR_TX_COMMISSION) VALUES ('1', '1', 'RICHARD', 'Arsne', '1', '21000', '2');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT) VALUES ('1', '1', 'POUNTY', 'Thomas', '4', '16300');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT) VALUES ('1', '1', 'DIALO', 'Jean-Pierre', '4', '16300');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT) VALUES ('1', '1', 'FOREST', 'Mamadou', '4', '16300');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT) VALUES ('1', '2', 'FLAIR', 'Dominique', '2', '19550');
/
INSERT INTO V_SALARIES (SLR_STE, SLR_SRV, SLR_NOM, SLR_PRENOM, SLR_QUA, SLR_SALAN_BRUT) VALUES ('1', '3', 'BADOUR', 'Ali', '6', '18000');
/

CREATE TABLE  V_CLIENTS
(CLI_NUM NUMBER,          -- Cle unique sequentielle
  CLI_STE NUMBER,          -- Societe
  CLI_NOM VARCHAR2(100),            -- Nom Client
	CLI_TELF VARCHAR2(255),   -- tel fixe du responsable
	CLI_TELM VARCHAR2(255),   -- tel mobile du responsable
	CLI_MAIL1 VARCHAR2(255),   -- mail1 fixe du responsable
	CLI_ADR  VARCHAR2(255), -- Adresse
	CLI_CPO VARCHAR2(5), -- Code postal
	CLI_VILLE VARCHAR2(255), -- ville
  CLI_LATITUDE VARCHAR2(255), -- latitude
  CLI_LONGITUDE VARCHAR2(255), 	-- longitude
  CLI_TXTVA  NUMBER,               -- Code TVA
  CLI_CA_HT NUMBER(9,2),         -- CA HT annuel cumule
  CLI_ENCOURS_AUTORISE NUMBER(9,2), -- Montant HT en cours autorise
  CLI_SLR NUMBER,                   -- commercial

	CONSTRAINT V_CLIENTS_PK PRIMARY KEY (CLI_NUM) ENABLE,
	
	CONSTRAINT V_CLIENTS_FK1 FOREIGN KEY (CLI_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE,
	CONSTRAINT V_CLIENTS_FK2 FOREIGN KEY (CLI_SLR) REFERENCES V_SALARIES (SLR_NUM) ENABLE	
   );
/


CREATE SEQUENCE   V_CLIENTS_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE
/

CREATE OR REPLACE TRIGGER  V_CLIENTS_BI
  before insert on V_CLIENTS          
  for each row  
begin   
    select V_CLIENTS_SEQ.nextval into :NEW.CLI_NUM from dual; 
end; 

/
ALTER TRIGGER  V_CLIENTS_BI ENABLE;
/

INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Patricia LOMBERT', '0472341280', '0667220199', 'patricia@lombert@neuf.fr', '12 RUE ROGER SALENGRO', '69029', 'BRON', '1', '500', '3');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Ludovic RONARD', '0478023301', '0667309288', 'ludovic.ronard@hotmail.fr', '6 RUE DE L''ORATOIRE', '69300', 'CALUIRE ET CUIRE', '1', '500', '3');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Larbi MALOUK', '0437504327', '0635930093', 'larbi.malouk@gmail.com', '15 RUE DE LA SOLIDARITE', '69100', 'VILLEURBANNE', '1', '300', '3');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Angelo GARCIA', '0478910223', '0667932388', 'angelo.garcia@free.fr', '120 RUE MASSENA', '69003', 'LYON', '1', '300', '3');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Robert SIMON', '0472349800', '0645012993', 'robert.simon@laposte.net', '20 PLACE BELLECOUR', '69002', 'LYON', '1', '1000', '3');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Sabrina GERARD', '0478890123', '0667239902', 'sabrina.gerard@free.fr', '80 ROUTE NATIONALE', '69380', 'LES CHERES', '1', '300', '3');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Farid LASMA', '0478924556', '0645980498', 'farid.lasma@neuf.fr', '10 AVENUE EDOUARD PAYEN', '69130', 'ECULLY', '1', '300', '3');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Delphine BERGER', '0472120988', '0669029934', 'delphine.berger@gmail.com', '20 RUE ANATOLE ROYBET', '69740', 'GENAS', '1', '500', '4');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Fabienne COUROT', '0472039909', '0667196746', 'fabienne.courot@hotmail.com', '50 RUE VILLON', '69003', 'LYON', '1', '500', '4');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Brigitte SOMI', '0437029943', '0642349985', 'brigitte.somi435@aol.com', '2 RUE MOURGUET', '69005', 'LYON', '1', '1000', '4');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Albert COHEN', '0472014456', '0676080230', 'albert.cohen@free.fr', '62 RUE DE LA REPUBLIQUE', '69002', 'LYON', '1', '0', '4');
/
INSERT INTO V_CLIENTS (CLI_STE, CLI_NOM, CLI_TELF, CLI_TELM, CLI_MAIL1, CLI_ADR, CLI_CPO, CLI_VILLE, CLI_TXTVA, CLI_ENCOURS_AUTORISE, CLI_SLR) VALUES ('1', 'Barak O''dinga', '0478910197', '0678983376', 'barako@gmail.com', '5 RUE RADISSON', '69170', 'TARARE', '1', '0', '4');
/

CREATE TABLE  V_FAMILLES_ARTICLES
(FAM_NUM NUMBER,          -- Cle unique sequentielle
  FAM_STE NUMBER,          -- Societe
	FAM_NOM_ABREGE VARCHAR2(100),   -- Nom court
	FAM_NOM_COMPLET VARCHAR2(255),   -- Nom complet

	CONSTRAINT V_FAMILLES_ARTICLES_PK PRIMARY KEY (FAM_NUM) ENABLE,
	
	CONSTRAINT V_FAMILLES_ARTICLES_FK1 FOREIGN KEY (FAM_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE	
   );
/


CREATE SEQUENCE   V_FAMILLES_ARTICLES_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_FAMILLES_ARTICLES_BI
  before insert on V_FAMILLES_ARTICLES               
  for each row  
begin   
    select V_FAMILLES_ARTICLES_SEQ.nextval into :NEW.FAM_NUM from dual; 
end; 

/
ALTER TRIGGER  V_FAMILLES_ARTICLES_BI ENABLE;
/

INSERT INTO V_FAMILLES_ARTICLES (FAM_STE, FAM_NOM_ABREGE, FAM_NOM_COMPLET) VALUES ('1', 'Jeux et consoles', 'Jeux et consoles');
/
INSERT INTO V_FAMILLES_ARTICLES (FAM_STE, FAM_NOM_ABREGE, FAM_NOM_COMPLET) VALUES ('1', 'Films DVD', 'Films DVD');
/
INSERT INTO V_FAMILLES_ARTICLES (FAM_STE, FAM_NOM_ABREGE, FAM_NOM_COMPLET) VALUES ('1', 'Tlphonie mobiles', 'Tlphonie mobiles');
/
INSERT INTO V_FAMILLES_ARTICLES (FAM_STE, FAM_NOM_ABREGE, FAM_NOM_COMPLET) VALUES ('1', 'Photos', 'Photos');
/


CREATE TABLE  V_ARTICLES 
(ART_NUM NUMBER,          -- Cle unique sequentielle
  ART_STE NUMBER,          -- Societe
  ART_FAM NUMBER,            -- Service
	ART_LIBELLE VARCHAR2(50),   -- Libell article 
  ART_DESIGNATION VARCHAR2(255),  -- Dsignation article
  ART_PRIX_UNITAIRE NUMBER(7,2), -- prix unitaire HT
  ART_EN_STOCK NUMBER,      -- Quantite en stock disponible
  ART_IMAGE BLOB,              -- Logo   
	ART_TYPEMIME VARCHAR2(255),    -- type mime
	ART_NOMFICHIER VARCHAR2(400),  -- nom fichier logo
	ART_DATE_MODIFICATION DATE,   -- date modification logo
	
	CONSTRAINT V_ARTICLES_PK PRIMARY KEY (ART_NUM) ENABLE,
	
	CONSTRAINT V_ARTICLES_FK1 FOREIGN KEY (ART_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE,	
	CONSTRAINT V_ARTICLES_FK2 FOREIGN KEY (ART_FAM) REFERENCES V_FAMILLES_ARTICLES (FAM_NUM) ENABLE
   );
/


CREATE SEQUENCE   V_ARTICLES_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_ARTICLES_BI
  before insert on V_ARTICLES             
  for each row  
begin   
    select V_ARTICLES_SEQ.nextval into :NEW.ART_NUM from dual; 
end; 

/
ALTER TRIGGER  V_ARTICLES_BI ENABLE;
/

INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '1', 'Samantha oups ! volume 1', '4', '122');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '1', 'Samantha oups ! volume 2 ', '4', '221');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '1', 'Fifa 09 Nintendo DS', '14', '21');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '1', 'Lego batman - ps2', '12', '32');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '1', 'Console sony playstation 3 - ps3 80 go', '350', '102');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '2', 'La lgende de Zorro DVD', '9', '76');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '2', 'Cash DVD', '15', '43');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '2', 'Harry Potter An 1  5 coffret  10 DVD', '50', '23');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '2', 'Grey''s anatomy - saison 1', '23', '221');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '2', 'Grey''s anatomy - saison 2', '23', '92');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '2', 'Grey''s anatomy - saison 3', '23', '32');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '3', 'Tlphone portable w156', '19', '98');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '3', 'Tlphone portable s500i noir', '98', '65');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '3', 'Tlphone portable sgh-f480 marron - player', '320', '54');
/
INSERT INTO V_ARTICLES (ART_STE, ART_FAM, ART_LIBELLE, ART_PRIX_UNITAIRE, ART_EN_STOCK) VALUES ('1', '4', 'Appareil photo numrique lumix dmc-fx40 - noir', '190', '21');
/


CREATE TABLE  V_COMMANDES 
(CDE_NUM NUMBER,          -- Cle unique sequentielle
  CDE_STE NUMBER,          -- Societe
  CDE_CLI NUMBER,            -- Client
  CDE_DATE_COMMANDE DATE,             -- Date commande
  CDE_DATE_LIVRAISON DATE,   -- Date livraison previsionnelle
  CDE_MT_HT NUMBER(7,2),         -- Montant HT commande
  CDE_SLR NUMBER,                -- N livreur

	CONSTRAINT V_COMMANDES_PK PRIMARY KEY (CDE_NUM) ENABLE,
	
	CONSTRAINT V_COMMANDES_FK1 FOREIGN KEY (CDE_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE,	
	CONSTRAINT V_COMMANDES_FK2 FOREIGN KEY (CDE_CLI) REFERENCES V_CLIENTS (CLI_NUM) ENABLE,
	CONSTRAINT V_COMMANDES_FK3 FOREIGN KEY (CDE_SLR) REFERENCES V_SALARIES (SLR_NUM) ENABLE
   );
/


CREATE SEQUENCE   V_COMMANDES_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_COMMANDES_BI
  before insert on V_COMMANDES          
  for each row  
begin   
    select V_COMMANDES_SEQ.nextval into :NEW.CDE_NUM from dual; 
end; 

/
ALTER TRIGGER  V_COMMANDES_BI ENABLE;
/

INSERT INTO V_COMMANDES 
(CDE_STE , CDE_CLI , CDE_DATE_COMMANDE , CDE_DATE_LIVRAISON , CDE_MT_HT ,	CDE_SLR) VALUES
('1' ,	'11' ,	'24/06/09' ,	'28/06/09' ,	'50' ,	'7');
/
INSERT INTO V_COMMANDES 
(CDE_STE , CDE_CLI , CDE_DATE_COMMANDE , CDE_DATE_LIVRAISON , CDE_MT_HT ,	CDE_SLR) VALUES
('1' ,	'10' ,	'25/06/09' ,	'29/06/09' ,	'127' ,	'6');
/
INSERT INTO V_COMMANDES 
(CDE_STE , CDE_CLI , CDE_DATE_COMMANDE , CDE_DATE_LIVRAISON , CDE_MT_HT ,	CDE_SLR) VALUES
('1' ,	'12' ,	'07/07/09' ,	'15/07/09' ,	'190'	, '5');
/
INSERT INTO V_COMMANDES 
(CDE_STE , CDE_CLI , CDE_DATE_COMMANDE , CDE_DATE_LIVRAISON , CDE_MT_HT ,	CDE_SLR) VALUES
('1' ,	 '7' ,	'30/06/09' ,	'06/07/09' ,	'12' ,	'6');
/

CREATE TABLE  V_LIGNES_COMMANDES 
(LCD_NUM NUMBER,          -- Cle unique sequentielle
  LCD_CDE NUMBER,          -- numero commande
  LCD_ART NUMBER,          -- numero article
  LCD_STE NUMBER,          -- Societe
  LCD_QTE NUMBER,          -- Quantite commandee
  LCD_PU  NUMBER(7,2),           -- PU HT
  LCD_MT  NUMBER(9,2),             -- Montant HT ligne


	CONSTRAINT V_LIGNES_COMMANDES_PK PRIMARY KEY (LCD_NUM) ENABLE,
	
	CONSTRAINT V_LIGNES_COMMANDES_FK1 FOREIGN KEY (LCD_STE) REFERENCES V_SOCIETES (STE_NUM) ENABLE,	
	CONSTRAINT V_LIGNES_COMMANDES_FK2 FOREIGN KEY (LCD_CDE) REFERENCES V_COMMANDES (CDE_NUM) ENABLE,
	CONSTRAINT V_LIGNES_COMMANDES_FK3 FOREIGN KEY (LCD_ART) REFERENCES V_ARTICLES (ART_NUM) ENABLE
   );
/


CREATE SEQUENCE   V_LIGNES_COMMANDES_SEQ  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;
/

CREATE OR REPLACE TRIGGER  V_LIGNES_COMMANDES_BI
  before insert on V_LIGNES_COMMANDES          
  for each row  
begin   
    select V_LIGNES_COMMANDES_SEQ.nextval into :NEW.LCD_NUM from dual; 
end; 

/
ALTER TRIGGER  V_LIGNES_COMMANDES_BI ENABLE;
/

INSERT INTO V_LIGNES_COMMANDES (LCD_CDE , LCD_ART , LCD_STE , LCD_QTE , LCD_PU , LCD_MT) 
VALUES
('1'	,'1'	, '1'	, '1'	, '4'	, '4');
/
INSERT INTO V_LIGNES_COMMANDES (LCD_CDE , LCD_ART , LCD_STE , LCD_QTE , LCD_PU , LCD_MT) 
VALUES
('1'	, '10' , '1' ,	'1' ,	'23' ,	'23');
/
INSERT INTO V_LIGNES_COMMANDES (LCD_CDE , LCD_ART , LCD_STE , LCD_QTE , LCD_PU , LCD_MT) 
VALUES
('1' ,	'11' ,	'1' ,	'1' ,	'23' ,	'23');
/
INSERT INTO V_LIGNES_COMMANDES (LCD_CDE , LCD_ART , LCD_STE , LCD_QTE , LCD_PU , LCD_MT) 
VALUES
('2'	, '8' ,	'1' ,	'2' ,	'50' ,	'100');
/
INSERT INTO V_LIGNES_COMMANDES (LCD_CDE , LCD_ART , LCD_STE , LCD_QTE , LCD_PU , LCD_MT) 
VALUES
('2'	, '6'	, '1'	, '3'	, '9' ,	'27');
/
INSERT INTO V_LIGNES_COMMANDES (LCD_CDE , LCD_ART , LCD_STE , LCD_QTE , LCD_PU , LCD_MT) 
VALUES
('3'	, '15' , '1' ,	'1' ,	'190' ,	'190');
/
INSERT INTO V_LIGNES_COMMANDES (LCD_CDE , LCD_ART , LCD_STE , LCD_QTE , LCD_PU , LCD_MT) 
VALUES
('4'	, '4' ,	'1' ,	'1' ,	'12' ,	'12');
/